=============
API Reference
=============

Application Configuration
=========================
.. autoclass:: divak.api.Recorder
   :members:

Header Modifiers
================
.. autoclass:: divak.api.RequestIdPropagator
   :members:

Observation Points
==================
.. autoclass:: divak.api.Logger
   :members:

Test Helpers
============
.. autoclass:: divak.testing.RecordingLogHandler
   :members:
